@@ -1,36 +1,32 @@
-(* Otags reloaded
+(* Otags III
  * 
  * Hendrik Tews Copyright (C) 2010 - 2016
  * 
- * This file is part of "Otags reloaded".
+ * This file is part of "Otags III".
  * 
- * "Otags reloaded" is free software: you can redistribute it and/or
+ * "Otags III" is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation, either version 3 of the
  * License, or (at your option) any later version.
  * 
- * "Otags reloaded" is distributed in the hope that it will be useful,
+ * "Otags III" is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License in file COPYING in this or one of the parent
  * directories for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with "Otags reloaded". If not, see
+ * along with "Otags III". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: emacs.ml,v 1.13 2016/01/10 20:57:39 tews Exp $
- * 
  * write emacs tags files
  * 
  *)
 
 open Global
-open Types
+open Otags_types
 open Source_channel
 
-module Loc = Camlp4.PreCast.Loc
-
 
 (* For files with INCLUDE or line directives we suddenly get tags with
  * locations from different files. We cannot tag with the main source file
@@ -79,7 +75,7 @@ let emacs_tag_line line tag line_number char =
 let start_unit es file =
   assert(file <> "");
   assert(Hashtbl.length es.buffers = 0);
-  let mod_name = Misc.module_name file in
+  let mod_name = Otags_misc.module_name file in
   let module_tag = emacs_tag_line "" mod_name 1 0 in
   make_current_buffer es file;
   Buffer.add_string es.current_buf module_tag
@@ -93,15 +89,36 @@ let write_tag es loc tag =
    *   (Loc.start_bol loc)
    *   (Misc.cut_out (get_channel loc) (Loc.start_bol loc) (Loc.stop_off loc));
    *)
-  if es.file <> Loc.file_name loc 
+  if es.file <> Otags_misc.file_of_loc loc 
   then 
-    make_current_buffer es (Loc.file_name loc);
+    make_current_buffer es (Otags_misc.file_of_loc loc);
+  let line_fragment =
+    (* if loc is wrong (eg, because of line directives) cut_out will
+     * throw End_of_file.
+     *)
+    try
+      Otags_misc.cut_out
+	(get_channel loc)
+	loc.Location.loc_start.Lexing.pos_bol
+	loc.Location.loc_end.Lexing.pos_cnum
+    with
+      | End_of_file ->
+	 raise
+	   (Otags_parsing_error(
+		loc,
+		(Printf.sprintf
+		   ("The parser delivered an invalid location "
+		    ^^ "(char position %d-%d),\n"
+		    ^^ "maybe there are line directives in the input?")
+		   loc.Location.loc_start.Lexing.pos_bol
+		   loc.Location.loc_end.Lexing.pos_cnum)))
+  in
   Buffer.add_string es.current_buf 
     (emacs_tag_line
-       (Misc.cut_out (get_channel loc) (Loc.start_bol loc) (Loc.stop_off loc))
+       line_fragment
        tag
-       (Loc.start_line loc)
-       (Loc.start_bol loc))
+       loc.Location.loc_start.Lexing.pos_lnum
+       loc.Location.loc_start.Lexing.pos_bol)
 
 
   (* Buffer, never to be really used, serves as a placeholder for the
