@@ -1,34 +1,31 @@
-(* Otags reloaded
+(* Otags III
  * 
  * Hendrik Tews Copyright (C) 2010 - 2016
  * 
- * This file is part of "Otags reloaded".
+ * This file is part of "Otags III".
  * 
- * "Otags reloaded" is free software: you can redistribute it and/or
+ * "Otags III" is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation, either version 3 of the
  * License, or (at your option) any later version.
  * 
- * "Otags reloaded" is distributed in the hope that it will be useful,
+ * "Otags III" is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License in file COPYING in this or one of the parent
  * directories for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with "Otags reloaded". If not, see
+ * along with "Otags III". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: source_channel.ml,v 1.4 2016/01/10 20:57:40 tews Exp $
- * 
  * hold the in_channel of the source file
  * 
  *)
 
 
-open Types				(* for Otags_parsing_error *)
-module Loc = Camlp4.PreCast.Loc
-
+open Otags_misc
+open Otags_types			(* for Otags_parsing_error *)
 
 let current_file_name = ref ""
 
@@ -57,15 +54,17 @@ let open_file ?(primary_file = false) file_name loc =
 
 
 let get_channel ?primary_file loc =
-  if Loc.file_name loc <> !current_file_name
-  then open_file ?primary_file (Loc.file_name loc) loc;
+  if file_of_loc loc  <> !current_file_name
+  then open_file ?primary_file (file_of_loc loc) loc;
   !current_in_channel
     
 
 
-let full_string_of_loc loc =
-  Printf.sprintf "[%s: sl %d(%d) so %d el %d(%d) eo %d%s]"
-    (Loc.file_name loc)
-    (Loc.start_line loc) (Loc.start_bol loc) (Loc.start_off loc)
-    (Loc.stop_line loc) (Loc.stop_bol loc) (Loc.stop_off loc)
-    (if Loc.is_ghost loc then " GHOST" else " REAL")
+let full_string_of_loc _loc = "XXX"
+  (* XXX fix
+   * Printf.sprintf "[%s: sl %d(%d) so %d el %d(%d) eo %d%s]"
+   *   (Loc.file_name loc)
+   *   (Loc.start_line loc) (Loc.start_bol loc) (Loc.start_off loc)
+   *   (Loc.stop_line loc) (Loc.stop_bol loc) (Loc.stop_off loc)
+   *   (if Loc.is_ghost loc then " GHOST" else " REAL")
+   *)
