@@ -28,6 +28,15 @@ end
 
 module type c13
 
+module C4 = C3
+
+type c5 = ..
+
+type c5 += C6 of int * string
+
+type c5 += C7
+	      
+
 (*** Local Variables: ***)
 (*** compile-command: "make -C .. test" ***)
 (*** End: ***)
