@@ -1,36 +1,32 @@
-(* Otags reloaded
+(* Otags III
  * 
  * Hendrik Tews Copyright (C) 2010 - 2016
  * 
- * This file is part of "Otags reloaded".
+ * This file is part of "Otags III".
  * 
- * "Otags reloaded" is free software: you can redistribute it and/or
+ * "Otags III" is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation, either version 3 of the
  * License, or (at your option) any later version.
  * 
- * "Otags reloaded" is distributed in the hope that it will be useful,
+ * "Otags III" is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * General Public License in file COPYING in this or one of the parent
  * directories for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with "Otags reloaded". If not, see
+ * along with "Otags III". If not, see
  * <http://www.gnu.org/licenses/>.
  * 
- * $Id: vi.ml,v 1.11 2016/01/10 20:57:40 tews Exp $
- * 
  * write vi tags files
  * 
  *)
 
 open Global
-open Types
+open Otags_types
 open Source_channel
 
-module Loc = Camlp4.PreCast.Loc
-
 
 type vi_tag = {
   tag : string;
@@ -132,21 +128,39 @@ let add_tag vs tag =
 
 
 let start_unit vs file =
-  let mod_name = Misc.module_name file in
+  let mod_name = Otags_misc.module_name file in
   add_tag vs {tag = mod_name; tag_file = file; address = "1"; position = 0}
 
 
 let write_tag vs loc tag = 
-  let loc_line = Misc.input_line_at (get_channel loc) (Loc.start_bol loc) in
+  let loc_line =
+    (* if loc is wrong (eg, because of line directives), input_line
+     * will throw End_of_file.
+     *)
+    try
+      Otags_misc.input_line_at (get_channel loc)
+			       loc.Location.loc_start.Lexing.pos_bol
+    with
+      | End_of_file ->
+	 raise
+	   (Otags_parsing_error(
+		loc,
+		(Printf.sprintf
+		   ("The parser delivered an invalid location "
+		    ^^ "(char position %d-%d),\n"
+		    ^^ "maybe there are line directives in the input?")
+		   loc.Location.loc_start.Lexing.pos_bol
+		   loc.Location.loc_end.Lexing.pos_cnum)))
+ in
   let address = 
     if String.length loc_line <= 1
-    then string_of_int (Loc.start_line loc)
+    then string_of_int loc.Location.loc_start.Lexing.pos_lnum
     else ex_search_line loc_line
   in
   add_tag vs {tag = tag; 
-	      tag_file = Loc.file_name loc;
+	      tag_file = Otags_misc.file_of_loc loc;
 	      address = address;
-	      position = Loc.start_off loc;
+	      position = loc.Location.loc_start.Lexing.pos_cnum;
 	     }
 
 
